@@ -306,7 +306,7 @@ function alis_install_package() {
           ;;
         gnome)
           ALL_PACKAGES+=(gnome gnome-extra matcha-gtk-theme xcursor-breeze papirus-maia-icon-theme-git ttf-dejavu noto-fonts ttf-liberation gnome-shell-extensions gnome-shell-extension-topicons-plus chrome-gnome-shell evolution-ews evolution-on)
-          ALL_CONFIG+=(gnome_terminal_transparency_user gnome_system)
+          ALL_CONFIG+=(gnome_terminal_transparency_user gnome_bluetooth_user gnome_system)
           ;;
         docker)
           ALL_PACKAGES+=(docker docker-compose)
@@ -568,6 +568,11 @@ EOT
     install_aur_packages gnome-terminal-transparency
   }
 
+  function gnome_bluetooth_user() {
+    uninstall_aur_packages gnome-bluetooth
+    install_aur_packages gnome-bluetooth-pantheon
+  }
+
   function docker_system() {
     systemctl enable docker
     systemctl start docker.service
@@ -637,11 +642,13 @@ function alis_config_minimum() {
   local TIMEZONE="$5"
   local DEVICE
   DEVICE=$(working_device)
+  local DEFAULT_SWAP_SIZE
+  DEFAULT_SWAP_SIZE=$(grep MemTotal /proc/meminfo | awk '{$2/=1024; $2=int($2); print $2}')
 
   : "${ROOT_PASSWORD:=admin}"
   : "${ARCH_NAME:=archlinux}"
   : "${SEC_LOCALE:=en_US}"
-  : "${SWAP_SIZE:=4192}"
+  : "${SWAP_SIZE:=$DEFAULT_SWAP_SIZE}"
 
   refactor_mirror_list
 
